EntryModel class

Constructors

EntryModel({String? id, String? transactionNumber, String? transactionType, String? accountName, String? accountNumber, String? accountProductName, DateTime? branchDate, String? currency, double? debitAmount, double? creditAmount, DateTime? createdAt})

Properties

accountName String?
getter/setter pair
accountNumber String?
getter/setter pair
accountProductName String?
getter/setter pair
branchDate DateTime?
getter/setter pair
createdAt DateTime?
getter/setter pair
creditAmount double?
getter/setter pair
currency String?
getter/setter pair
debitAmount double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionNumber String?
getter/setter pair
transactionType String?
getter/setter pair
updatedAt DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited