ReversedTnxEntryModel class

Constructors

ReversedTnxEntryModel({String? transactionId, String? accountNumber, DateTime? branchDate, String? transactionType, double? transactionAmount, String? maker, String? approver})

Properties

accountNumber String?
getter/setter pair
approver String?
getter/setter pair
branchDate DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maker String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionAmount double?
getter/setter pair
transactionId String?
getter/setter pair
transactionType String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited